import random


class RandomCube:
    def __ini__(self):
        pass

    def GetResult(self):
        return random.randint(1, 7)


#Comment number 0.9962170584519742
#Comment number 0.47219000941449707
#Comment number 0.6049586928817927
#Comment number 0.7063835297671106
#Comment number 0.7189834392941379
#Comment number 0.09051145125997839
#Comment number 0.17351339592243176